﻿using System;
using System.Threading;
using System.IO.Ports;
using CPUCoolerTester;

namespace ThermalResistance
{
    class Program
    {
        static void Main(string[] args)
        {
            var brd = new Wrapper(SerialPort.GetPortNames()[0]);
            brd.Reset();

            Console.WriteLine("setting power to 0 watts");
            brd.SetConfig(0, 100);

            Console.WriteLine("waiting 180 seconds");
            Wait(brd, 180);

            var s0 = brd.GetStatus();
            ThrowIfAlarm(s0);
            Console.WriteLine("T0 = {0}", s0.Temp);

            Console.WriteLine("setting power to 50 watts");
            brd.SetConfig(50, 100);

            Console.WriteLine("waiting 180 seconds");
            Wait(brd, 180);

            var s50 = brd.GetStatus();
            ThrowIfAlarm(s50);
            Console.WriteLine("T50 = {0}", s50.Temp);

            var r = (s50.Temp - s0.Temp) / 50.0;
            Console.WriteLine("Thermal resistance = {0} K/W", r);

            Console.ReadKey();
        }

        static void Wait(Wrapper brd, int seconds)
        {
            for (var i = 0; i < seconds; i++)
            {
                ThrowIfAlarm(brd.GetStatus());
                Thread.Sleep(1000);
            }
        }

        static void ThrowIfAlarm(Wrapper.Status status)
        {
            if (status.State != Wrapper.State.OK)
            {
                throw new Exception();
            }
        }
    }
}
